@@ -74,13 +74,13 @@ SetupSSL(void)
 {
     if (ctx == (SSL_CTX *)0) {
 	char *ciphers;
-#if OPENSSL_VERSION_NUMBER < 0x10100000L
+# if OPENSSL_VERSION_NUMBER < 0x10100000L
 	SSL_load_error_strings();
 	if (!SSL_library_init()) {
 	    Error("SSL library initialization failed");
 	    Bye(EX_UNAVAILABLE);
 	}
-#endif /* OPENSSL_VERSION_NUMBER < 0x10100000L */
+# endif/* OPENSSL_VERSION_NUMBER < 0x10100000L */
 	if ((ctx = SSL_CTX_new(TLS_method())) == (SSL_CTX *)0) {
 	    Error("Creating SSL context failed");
 	    Bye(EX_UNAVAILABLE);
@@ -910,11 +910,19 @@ ExecCmd(void)
     /* setup new process with clean file descriptors
      * stderr still goes to stderr...so user sees it
      */
-    i = GetMaxFiles();
-    for ( /* i above */ ; --i > 3;) {
+#ifdef HAVE_CLOSEFROM
+    for (i = 3; i <= pout[0] || i <= pin[1]; i++) {
 	if (i != pout[0] && i != pin[1])
 	    close(i);
     }
+    closefrom(i);
+#else
+    i = GetMaxFiles();
+    for ( /* i above */ ; --i > 2;) {
+	if (i != pout[0] && i != pin[1])
+	    close(i);
+    }
+#endif
     close(1);
     close(0);
 
@@ -1755,6 +1763,12 @@ DoCmds(char *master, char *pports, int cmdi)
 		}
 		FileWrite(pcf, FLAGFALSE, "exit\r\n", 6);
 		t = ReadReply(pcf, FLAGTRUE);
+	    } else if (interact == FLAGFALSE && result[0] == '[' &&
+		       cmdi > 0) {
+		FileClose(&pcf);
+		/* reconnect to same, but with the next command (info, examine, etc) */
+		DoCmds(master, pports, cmdi - 1);
+		break;
 	    } else {
 		/* if we're not trying to connect to a console */
 		if (interact == FLAGFALSE) {
@@ -1859,7 +1873,7 @@ DoCmds(char *master, char *pports, int cmdi)
 	FileClose(&pcf);
 
 	/* this would only be true if we got extra redirects (@... above) */
-	if (cmds[cmdi][0] == 'c' && interact == FLAGTRUE)
+	if (cmds[cmdi][0] == 'c')
 	    DoCmds(server, result, cmdi);
 	else if (cmdi > 0)
 	    DoCmds(server, result, cmdi - 1);
